pub enum ActivationError {
LoadCachedToken(CachedTokenError),
SaveCachedToken(Error),
FetchActivationUrl(MoonbaseApiError),
FetchActivationState(MoonbaseApiError),
OfflineToken(OfflineTokenValidationError),
}Expand description
Errors that can occur during the activation process.
Variants
LoadCachedToken(CachedTokenError)
An error occurred when validating a cached token.
SaveCachedToken(Error)
Could not persist the token to disk for caching purposes.
FetchActivationUrl(MoonbaseApiError)
Could not fetch the online activation URL from the Moonbase API.
FetchActivationState(MoonbaseApiError)
Could not fetch the activation state of an online token from the Moonbase API.
OfflineToken(OfflineTokenValidationError)
Could not validate an offline token provided by the user.