LicenseActivationConfig

Struct LicenseActivationConfig 

pub struct LicenseActivationConfig {
    pub vendor_id: String,
    pub product_id: String,
    pub jwt_pubkey: String,
    pub cached_token_path: PathBuf,
    pub device_name: String,
    pub device_signature: String,
    pub online_token_refresh_threshold: Duration,
    pub online_token_expiration_threshold: Duration,
}
Configuration options for the LicenseActivator.

Fields

vendor_id: String

The Moonbase vendor id for the store. Used to determine the API endpoint, i.e. https://{vendor_id}.moonbase.sh

product_id: String

The Moonbase product id that a license needs to be valid for.

jwt_pubkey: String

The public key to verify the signed JWT payload.

cached_token_path: PathBuf

The path where the cached license token payload is stored on disk.

device_name: String

User-friendly display name of the device the software is running on. Reported to Moonbase when activating a license.

device_signature: String

The unique signature of the device the software is running on.

online_token_refresh_threshold: Duration

The age threshold beyond which the activator attempts to refresh online tokens. Before this age, the token is accepted without attempting any further online validation.

online_token_expiration_threshold: Duration

The age threshold beyond which an online token is deemed too old to trust and must be refreshed before being accepted.