ActivationMethod

Enum ActivationMethod 

pub enum ActivationMethod {
    Offline,
    Online,
}

Variants



Offline

The license has been activated offline and is irrevocable, therefore we mustn’t check license validity online.



Online

The license has been activated online and may have been revoked from this machine since. We should regularly ask Moonbase if the license is still valid.