pub enum ActivationState {
NeedsActivation(Option<String>),
Activated(LicenseTokenClaims),
}Expand description
Represents the software’s current activation state.
Variants
NeedsActivation(Option<String>)
The plugin requires activation.
The provided String contains the URL to open in the user’s browser for online activation. If it is None, only offline activation is available at this point, but online activation may become available later with a new ActivationState.
Activated(LicenseTokenClaims)
The plugin has been successfully activated.