pub struct LicenseTokenClaims {
pub method: ActivationMethod,
pub product_latest_version: Option<String>,
pub user_name: String,
pub device_signature: String,
pub last_validated: DateTime<Utc>,
pub expires_at: Option<DateTime<Utc>>,
pub trial: bool,
}Expand description
The claims included in a validated license token provided by Moonbase.
Fields
method: ActivationMethodproduct_latest_version: Option<String>The latest release version of the product, if any.
user_name: StringThe name of the user that owns this license.
device_signature: StringThe signature of the device being activated. Should be checked against the user’s device signature.
last_validated: DateTime<Utc>The date and time at which the license token was last validated online.
expires_at: Option<DateTime<Utc>>The date and time at which the license expires.
trial: boolWhether this license token represents a time-limited trial (true), or an owned license (false).